@@ -1,6 +1,6 @@
 #' @title Helper function to retrieve species information from the ENSEMBL API
 #' @description This function interfaces with the ENSEMBL API
-#' (http://rest.ensembl.org/info/species?content-type=application/json)
+#' (https://rest.ensembl.org/info/species?content-type=application/json)
 #' and internally stores the output to use this information for subsequent
 #' retrieval function calls.
 #' @author Hajk-Georg Drost
@@ -25,34 +25,34 @@ get.ensembl.info <- function(update = FALSE) {
                     )
                 )
         )
-        
+
     } else {
-            
-        
-        rest_url <- "http://rest.ensembl.org/info/species?content-type=application/json"
+
+
+        rest_url <- "https://rest.ensembl.org/info/species?content-type=application/json"
         rest_api_status <- curl::curl_fetch_memory(rest_url)
         if (rest_api_status$status_code != 200) {
             message(
-                "The API 'http://rest.ensembl.org' does not seem to
+                "The API 'https://rest.ensembl.org' does not seem to
                 respond or work properly. Is the homepage 'http://rest.ensembl.org' currently available?",
                 " Could it be that there is a firewall issue on your side? Please re-run the function and check if it works now."
             )
         }
-    
+
             ensembl.info <-
                 tibble::as_tibble(
                     jsonlite::fromJSON(
                         rest_url
                     )$species
                 )
-        
+
         aliases <- groups <- NULL
         ensembl.info <-
             dplyr::select(ensembl.info, -aliases, -groups)
-        
+
         readr::write_tsv(ensembl.info,
                          file.path(tempdir(), "ensembl_info.tsv"))
     }
-    
+
     return(ensembl.info)
 }
