@@ -1,6 +1,6 @@
-#' @title Helper function to retrieve species information 
+#' @title Helper function to retrieve species information
 #' from the ENSEMBLGENOMES API
-#' @description This function interfaces with the ENSEMBL API 
+#' @description This function interfaces with the ENSEMBL API
 #' (http://rest.ensemblgenomes.org/info/species?content-type=application/json)
 #' and internally stores the output to use this information for subsequent
 #' retrieval function calls.
@@ -26,38 +26,38 @@ get.ensemblgenome.info <- function(update = FALSE) {
                     )
                 )
         )
-    
+
     } else {
-        
+
         message("Starting retrieval of information for all species stored in ENSEMBLGENOMES... This needs to be done only once.")
-        
-        rest_url <- "http://rest.ensembl.org/info/species?content-type=application/json"
+
+        rest_url <- "https://rest.ensembl.org/info/species?content-type=application/json"
         rest_api_status <- curl::curl_fetch_memory(rest_url)
-        
+
         if (rest_api_status$status_code != 200) {
             message(
-                "The API 'rest.ensembl.org' does not 
+                "The API 'rest.ensembl.org' does not
                 seem to respond or work properly.
-                Is the homepage 'rest.ensembl.org' 
-                currently available?", 
+                Is the homepage 'rest.ensembl.org'
+                currently available?",
                 " Could it be that there is a firewall issue on your side? Please re-run the function and check if it works now."
             )
         }
-        
+
             ensemblgenome.info <-
                 tibble::as_tibble(
                     jsonlite::fromJSON(
                         rest_url
                     )$species
                 )
-        
+
         aliases <- groups <- NULL
         ensemblgenome.info <-
             dplyr::select(ensemblgenome.info, -aliases, -groups)
-        
+
         readr::write_tsv(ensemblgenome.info,
                          file.path(tempdir(), "ensemblgenome_info.tsv"))
     }
-    
+
     return(ensemblgenome.info)
 }
