@@ -4,24 +4,24 @@ test_that("The getGenome() interface works properly for NCBI RefSeq (including w
     skip_on_cran()
     skip_on_travis()
     # test proper download from genbank
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "refseq",
             organism = "Saccharomyces cerevisiae",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
     
     # test proper use of internal referece files when command is repeated
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "refseq",
             organism = "Saccharomyces cerevisiae",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
 })
 
 
@@ -29,28 +29,28 @@ test_that("The getGenome() interface works properly for NCBI RefSeq using taxid.
     skip_on_cran()
     skip_on_travis()
     # test proper download from genbank
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "refseq",
             organism = "559292",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
 })
 
 test_that("The getGenome() interface works properly for NCBI RefSeq using assembly id..", {
     skip_on_cran()
     skip_on_travis()
     # test proper download from genbank
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "refseq",
             organism = "GCF_000146045.2",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
 })
 
 
@@ -59,72 +59,72 @@ test_that("The getGenome() interface works properly for NCBI Genbank (including
     skip_on_cran()
     skip_on_travis()
     # test proper download from genbank
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "genbank",
             organism = "Saccharomyces cerevisiae",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
     
     # test proper use of internal referece files when command is repeated
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "genbank",
             organism = "Saccharomyces cerevisiae",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
 })
 
 test_that("The getGenome() interface works properly for NCBI Genbank using taxid (including when command is repeated)..", {
     skip_on_cran()
     skip_on_travis()
     # test proper download from genbank
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "genbank",
             organism = "559292",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
     
     # test proper use of internal referece files when command is repeated
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "genbank",
             organism = "559292",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
 })
 
 test_that("The getGenome() interface works properly for NCBI Genbank using accession ids (including when command is repeated)..", {
     skip_on_cran()
     skip_on_travis()
     # test proper download from genbank
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "genbank",
             organism = "GCA_000146045.2",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
     
     # test proper use of internal referece files when command is repeated
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "genbank",
             organism = "GCA_000146045.2",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
 })
 
 test_that("The getGenome() interface works properly for ENSEMBL (including repeating function call)..",{
@@ -132,23 +132,23 @@ test_that("The getGenome() interface works properly for ENSEMBL (including repea
         skip_on_cran()
         skip_on_travis()    
     # test proper download from ENSEMBL
-        read_genome(
+        expect_output(read_genome(
             getGenome(
                 db       = "ensembl",
                 organism = "Saccharomyces cerevisiae",
                 path     = tempdir()
             ),
             format = "fasta"
-        )
+        ))
         
-        read_genome(
+        expect_output(read_genome(
             getGenome(
                 db       = "ensembl",
                 organism = "Saccharomyces cerevisiae",
                 path     = tempdir()
             ),
             format = "fasta"
-        )
+        ))
 })
 
 test_that("The getGenome() interface works properly for ENSEMBL using taxid (including repeating function call)..",{
@@ -156,23 +156,23 @@ test_that("The getGenome() interface works properly for ENSEMBL using taxid (inc
     skip_on_cran()
     skip_on_travis()    
     # test proper download from ENSEMBL
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "ensembl",
             organism = "4932",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
     
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "ensembl",
             organism = "4932",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
 })
 
 
@@ -181,140 +181,34 @@ test_that("The getGenome() interface works properly for ENSEMBL using accession
     skip_on_cran()
     skip_on_travis()    
     # test proper download from ENSEMBL
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "ensembl",
             organism = "GCA_000146045.2",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
     
-    read_genome(
+    expect_output(read_genome(
         getGenome(
             db       = "ensembl",
             organism = "GCA_000146045.2",
             path     = tempdir()
         ),
         format = "fasta"
-    )
+    ))
 })
 
-
-
-test_that("The getGenome() interface works properly for ENSEMBLGENOMES..", {
-    skip_on_cran()
-    skip_on_travis()
-    # test proper download from ENSEMBLGENOMES
-        read_genome(
-            getGenome(
-                db       = "ensemblgenomes",
-                organism = "Saccharomyces cerevisiae",
-                path     = tempdir()
-            ),
-            format = "fasta"
-        )
-})
-
-test_that("The getGenome() interface works properly for ENSEMBLGENOMES (including repeating command call)..", {
-    skip_on_cran()
-    skip_on_travis()
-    # test proper use of internal referece files when command is repeated
-        read_genome(
-            getGenome(
-                db       = "ensemblgenomes",
-                organism = "Saccharomyces cerevisiae",
-                path     = tempdir()
-            ),
-            format = "fasta"
-        )
-        
-        read_genome(
-            getGenome(
-                db       = "ensemblgenomes",
-                organism = "Saccharomyces cerevisiae",
-                path     = tempdir()
-            ),
-            format = "fasta"
-        )
-})
-
-
-test_that("The getGenome() error messages work properly for ENSEMBLGENOMES..",
-          {
-              skip_on_cran()
-              skip_on_travis()
-                  expect_equal(getGenome(
-                      db       = "ensemblgenomes",
-                      organism = "Saccharomyces cerevisi",
-                      path     = tempdir()
-                  ), FALSE)
-              
-          })
-
-
-
-test_that("The getGenome() interface works properly for ENSEMBLGENOMES using taxid (including repeating function call)..",{
-    
-    skip_on_cran()
-    skip_on_travis()    
-    # test proper download from ENSEMBLGENOMES
-    # read_genome(
-    #     getGenome(
-    #         db       = "ensemblgenomes",
-    #         organism = "4932",
-    #         path     = tempdir()
-    #     ),
-    #     format = "fasta"
-    # )
-    # 
-    # read_genome(
-    #     getGenome(
-    #         db       = "ensemblgenomes",
-    #         organism = "4932",
-    #         path     = tempdir()
-    #     ),
-    #     format = "fasta"
-    # )
-})
-
-
-test_that("The getGenome() interface works properly for ENSEMBLGENOMES using accession id (including repeating function call)..",{
-    
-    skip_on_cran()
-    skip_on_travis()    
-    # test proper download from ENSEMBLGENOMES
-    # read_genome(
-    #     getGenome(
-    #         db       = "ensemblgenomes",
-    #         organism = "GCA_000146045.2",
-    #         path     = tempdir()
-    #     ),
-    #     format = "fasta"
-    # )
-    # 
-    # read_genome(
-    #     getGenome(
-    #         db       = "ensemblgenomes",
-    #         organism = "GCA_000146045.2",
-    #         path     = tempdir()
-    #     ),
-    #     format = "fasta"
-    # )
-})
-
-
-
-
 test_that("The getGenome() error messages work properly for ENSEMBL..", {
     skip_on_cran()
     skip_on_travis()
     
-    getGenome(
+    expect_output(getGenome(
         db       = "ensembl",
         organism = "Saccharomyces cerevisi",
         path     = tempdir()
-    )
+    ))
 })
 
 test_that("The getGenome() error messages work properly for NCBI RefSeq", {
